KeyboardUtils class

Constructors

KeyboardUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isKeyboardOpen → bool
the current state of the keyboard. It is false if keyboard was not open for the first time.
no setter
keyboardHeight → double
the current height of the keyboard. if keyboard is closed, the height is 0.0.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add({required KeyboardListener listener}) → int
Subscribe to a keyboard event. listener object to listen the event. Returns a subscribing id that can be used to unsubscribe.
canCallDispose() → bool
dispose() → void
function to clear class on dispose.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllKeyboardListeners() → void
toString() → String
A string representation of this object.
inherited
unsubscribeListener({required int? subscribingId}) → bool
Unsubscribe from the keyboard visibility events subscribingId An id previously returned on add

Operators

operator ==(Object other) → bool
The equality operator.
inherited